# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/ganglion/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/ganglion/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.ganglion import ion_pb2 as neurion_dot_ganglion_dot_ion__pb2
from neurion.ganglion import params_pb2 as neurion_dot_ganglion_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19neurion/ganglion/tx.proto\x12\x10neurion.ganglion\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1aneurion/ganglion/ion.proto\x1a\x1dneurion/ganglion/params.proto\"\xaa\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32\x18.neurion.ganglion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:5\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\"neurion/x/ganglion/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xf8\x01\n\x0eMsgRegisterIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\ncapacities\x18\x02 \x03(\t\x12\r\n\x05stake\x18\x03 \x01(\x04\x12\x11\n\tendpoints\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0cinput_schema\x18\x06 \x01(\t\x12\x15\n\routput_schema\x18\x07 \x01(\t\x12\x1e\n\x16\x66\x65\x65_per_thousand_calls\x18\x08 \x01(\x04\x12\x1e\n\x16\x61llowed_pathway_owners\x18\t \x03(\t\x12\x0f\n\x07private\x18\n \x01(\x08:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgRegisterIonResponse\"M\n\x17MsgReportUnavailableIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0bion_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"!\n\x1fMsgReportUnavailableIonResponse\"O\n\x19MsgUnreportUnavailableIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0bion_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"#\n!MsgUnreportUnavailableIonResponse\"K\n\x0fMsgAddValidator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgAddValidatorResponse\"N\n\x12MsgRemoveValidator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRemoveValidatorResponse\"`\n\x17MsgValidateAvailability\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0bion_address\x18\x02 \x01(\t\x12\x11\n\tavailable\x18\x03 \x01(\x08:\x0c\x82\xe7\xb0*\x07\x63reator\"2\n\x1fMsgValidateAvailabilityResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x92\x01\n\x12MsgRegisterPathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tis_public\x18\x04 \x01(\x08\x12\x0c\n\x04ions\x18\x05 \x03(\t\x12\x19\n\x11\x66ield_maps_base64\x18\x06 \x03(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRegisterPathwayResponse\"L\n\x0fMsgStakePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgStakePathwayResponse\"c\n\x15MsgRefundPathwayStake\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x11\n\tnum_calls\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgRefundPathwayStakeResponse\"B\n\x15MsgInitUnstakePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgInitUnstakePathwayResponse\"4\n\x13MsgClaimProtocolFee\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1d\n\x1bMsgClaimProtocolFeeResponse\"c\n\x15MsgSettlePathwayStake\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x11\n\tnum_calls\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgSettlePathwayStakeResponse\"C\n\x12MsgStakeToGanglion\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgStakeToGanglionResponse\"/\n\x0eMsgClaimReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgClaimRewardResponse\"G\n\x16MsgUnstakeFromGanglion\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\" \n\x1eMsgUnstakeFromGanglionResponse\"\x9c\x01\n\x10MsgUpdatePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tis_public\x18\x05 \x01(\x08\x12\x0c\n\x04ions\x18\x06 \x03(\t\x12\x19\n\x11\x66ield_maps_base64\x18\x07 \x03(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgUpdatePathwayResponse\"-\n\x0cMsgRemoveIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgRemoveIonResponse\"=\n\x10MsgRemovePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgRemovePathwayResponse\">\n\x10MsgSetAllowedIps\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0b\n\x03ips\x18\x02 \x03(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgSetAllowedIpsResponse2\x9e\x10\n\x03Msg\x12\\\n\x0cUpdateParams\x12!.neurion.ganglion.MsgUpdateParams\x1a).neurion.ganglion.MsgUpdateParamsResponse\x12Y\n\x0bRegisterIon\x12 .neurion.ganglion.MsgRegisterIon\x1a(.neurion.ganglion.MsgRegisterIonResponse\x12t\n\x14ReportUnavailableIon\x12).neurion.ganglion.MsgReportUnavailableIon\x1a\x31.neurion.ganglion.MsgReportUnavailableIonResponse\x12z\n\x16UnreportUnavailableIon\x12+.neurion.ganglion.MsgUnreportUnavailableIon\x1a\x33.neurion.ganglion.MsgUnreportUnavailableIonResponse\x12\\\n\x0c\x41\x64\x64Validator\x12!.neurion.ganglion.MsgAddValidator\x1a).neurion.ganglion.MsgAddValidatorResponse\x12\x65\n\x0fRemoveValidator\x12$.neurion.ganglion.MsgRemoveValidator\x1a,.neurion.ganglion.MsgRemoveValidatorResponse\x12t\n\x14ValidateAvailability\x12).neurion.ganglion.MsgValidateAvailability\x1a\x31.neurion.ganglion.MsgValidateAvailabilityResponse\x12\x65\n\x0fRegisterPathway\x12$.neurion.ganglion.MsgRegisterPathway\x1a,.neurion.ganglion.MsgRegisterPathwayResponse\x12\\\n\x0cStakePathway\x12!.neurion.ganglion.MsgStakePathway\x1a).neurion.ganglion.MsgStakePathwayResponse\x12n\n\x12RefundPathwayStake\x12\'.neurion.ganglion.MsgRefundPathwayStake\x1a/.neurion.ganglion.MsgRefundPathwayStakeResponse\x12n\n\x12InitUnstakePathway\x12\'.neurion.ganglion.MsgInitUnstakePathway\x1a/.neurion.ganglion.MsgInitUnstakePathwayResponse\x12h\n\x10\x43laimProtocolFee\x12%.neurion.ganglion.MsgClaimProtocolFee\x1a-.neurion.ganglion.MsgClaimProtocolFeeResponse\x12n\n\x12SettlePathwayStake\x12\'.neurion.ganglion.MsgSettlePathwayStake\x1a/.neurion.ganglion.MsgSettlePathwayStakeResponse\x12\x65\n\x0fStakeToGanglion\x12$.neurion.ganglion.MsgStakeToGanglion\x1a,.neurion.ganglion.MsgStakeToGanglionResponse\x12Y\n\x0b\x43laimReward\x12 .neurion.ganglion.MsgClaimReward\x1a(.neurion.ganglion.MsgClaimRewardResponse\x12q\n\x13UnstakeFromGanglion\x12(.neurion.ganglion.MsgUnstakeFromGanglion\x1a\x30.neurion.ganglion.MsgUnstakeFromGanglionResponse\x12_\n\rUpdatePathway\x12\".neurion.ganglion.MsgUpdatePathway\x1a*.neurion.ganglion.MsgUpdatePathwayResponse\x12S\n\tRemoveIon\x12\x1e.neurion.ganglion.MsgRemoveIon\x1a&.neurion.ganglion.MsgRemoveIonResponse\x12_\n\rRemovePathway\x12\".neurion.ganglion.MsgRemovePathway\x1a*.neurion.ganglion.MsgRemovePathwayResponse\x12_\n\rSetAllowedIps\x12\".neurion.ganglion.MsgSetAllowedIps\x1a*.neurion.ganglion.MsgSetAllowedIpsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1aZ\x18neurion/x/ganglion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.ganglion.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/ganglion/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\"neurion/x/ganglion/MsgUpdateParams'
  _globals['_MSGREGISTERION']._loaded_options = None
  _globals['_MSGREGISTERION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREPORTUNAVAILABLEION']._loaded_options = None
  _globals['_MSGREPORTUNAVAILABLEION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNREPORTUNAVAILABLEION']._loaded_options = None
  _globals['_MSGUNREPORTUNAVAILABLEION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGADDVALIDATOR']._loaded_options = None
  _globals['_MSGADDVALIDATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEVALIDATOR']._loaded_options = None
  _globals['_MSGREMOVEVALIDATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGVALIDATEAVAILABILITY']._loaded_options = None
  _globals['_MSGVALIDATEAVAILABILITY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERPATHWAY']._loaded_options = None
  _globals['_MSGREGISTERPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKEPATHWAY']._loaded_options = None
  _globals['_MSGSTAKEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREFUNDPATHWAYSTAKE']._loaded_options = None
  _globals['_MSGREFUNDPATHWAYSTAKE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGINITUNSTAKEPATHWAY']._loaded_options = None
  _globals['_MSGINITUNSTAKEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMPROTOCOLFEE']._loaded_options = None
  _globals['_MSGCLAIMPROTOCOLFEE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSETTLEPATHWAYSTAKE']._loaded_options = None
  _globals['_MSGSETTLEPATHWAYSTAKE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKETOGANGLION']._loaded_options = None
  _globals['_MSGSTAKETOGANGLION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMREWARD']._loaded_options = None
  _globals['_MSGCLAIMREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMGANGLION']._loaded_options = None
  _globals['_MSGUNSTAKEFROMGANGLION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUPDATEPATHWAY']._loaded_options = None
  _globals['_MSGUPDATEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEION']._loaded_options = None
  _globals['_MSGREMOVEION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEPATHWAY']._loaded_options = None
  _globals['_MSGREMOVEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSETALLOWEDIPS']._loaded_options = None
  _globals['_MSGSETALLOWEDIPS']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=200
  _globals['_MSGUPDATEPARAMS']._serialized_end=370
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=372
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=397
  _globals['_MSGREGISTERION']._serialized_start=400
  _globals['_MSGREGISTERION']._serialized_end=648
  _globals['_MSGREGISTERIONRESPONSE']._serialized_start=650
  _globals['_MSGREGISTERIONRESPONSE']._serialized_end=674
  _globals['_MSGREPORTUNAVAILABLEION']._serialized_start=676
  _globals['_MSGREPORTUNAVAILABLEION']._serialized_end=753
  _globals['_MSGREPORTUNAVAILABLEIONRESPONSE']._serialized_start=755
  _globals['_MSGREPORTUNAVAILABLEIONRESPONSE']._serialized_end=788
  _globals['_MSGUNREPORTUNAVAILABLEION']._serialized_start=790
  _globals['_MSGUNREPORTUNAVAILABLEION']._serialized_end=869
  _globals['_MSGUNREPORTUNAVAILABLEIONRESPONSE']._serialized_start=871
  _globals['_MSGUNREPORTUNAVAILABLEIONRESPONSE']._serialized_end=906
  _globals['_MSGADDVALIDATOR']._serialized_start=908
  _globals['_MSGADDVALIDATOR']._serialized_end=983
  _globals['_MSGADDVALIDATORRESPONSE']._serialized_start=985
  _globals['_MSGADDVALIDATORRESPONSE']._serialized_end=1010
  _globals['_MSGREMOVEVALIDATOR']._serialized_start=1012
  _globals['_MSGREMOVEVALIDATOR']._serialized_end=1090
  _globals['_MSGREMOVEVALIDATORRESPONSE']._serialized_start=1092
  _globals['_MSGREMOVEVALIDATORRESPONSE']._serialized_end=1120
  _globals['_MSGVALIDATEAVAILABILITY']._serialized_start=1122
  _globals['_MSGVALIDATEAVAILABILITY']._serialized_end=1218
  _globals['_MSGVALIDATEAVAILABILITYRESPONSE']._serialized_start=1220
  _globals['_MSGVALIDATEAVAILABILITYRESPONSE']._serialized_end=1270
  _globals['_MSGREGISTERPATHWAY']._serialized_start=1273
  _globals['_MSGREGISTERPATHWAY']._serialized_end=1419
  _globals['_MSGREGISTERPATHWAYRESPONSE']._serialized_start=1421
  _globals['_MSGREGISTERPATHWAYRESPONSE']._serialized_end=1449
  _globals['_MSGSTAKEPATHWAY']._serialized_start=1451
  _globals['_MSGSTAKEPATHWAY']._serialized_end=1527
  _globals['_MSGSTAKEPATHWAYRESPONSE']._serialized_start=1529
  _globals['_MSGSTAKEPATHWAYRESPONSE']._serialized_end=1554
  _globals['_MSGREFUNDPATHWAYSTAKE']._serialized_start=1556
  _globals['_MSGREFUNDPATHWAYSTAKE']._serialized_end=1655
  _globals['_MSGREFUNDPATHWAYSTAKERESPONSE']._serialized_start=1657
  _globals['_MSGREFUNDPATHWAYSTAKERESPONSE']._serialized_end=1688
  _globals['_MSGINITUNSTAKEPATHWAY']._serialized_start=1690
  _globals['_MSGINITUNSTAKEPATHWAY']._serialized_end=1756
  _globals['_MSGINITUNSTAKEPATHWAYRESPONSE']._serialized_start=1758
  _globals['_MSGINITUNSTAKEPATHWAYRESPONSE']._serialized_end=1789
  _globals['_MSGCLAIMPROTOCOLFEE']._serialized_start=1791
  _globals['_MSGCLAIMPROTOCOLFEE']._serialized_end=1843
  _globals['_MSGCLAIMPROTOCOLFEERESPONSE']._serialized_start=1845
  _globals['_MSGCLAIMPROTOCOLFEERESPONSE']._serialized_end=1874
  _globals['_MSGSETTLEPATHWAYSTAKE']._serialized_start=1876
  _globals['_MSGSETTLEPATHWAYSTAKE']._serialized_end=1975
  _globals['_MSGSETTLEPATHWAYSTAKERESPONSE']._serialized_start=1977
  _globals['_MSGSETTLEPATHWAYSTAKERESPONSE']._serialized_end=2008
  _globals['_MSGSTAKETOGANGLION']._serialized_start=2010
  _globals['_MSGSTAKETOGANGLION']._serialized_end=2077
  _globals['_MSGSTAKETOGANGLIONRESPONSE']._serialized_start=2079
  _globals['_MSGSTAKETOGANGLIONRESPONSE']._serialized_end=2107
  _globals['_MSGCLAIMREWARD']._serialized_start=2109
  _globals['_MSGCLAIMREWARD']._serialized_end=2156
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_start=2158
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_end=2182
  _globals['_MSGUNSTAKEFROMGANGLION']._serialized_start=2184
  _globals['_MSGUNSTAKEFROMGANGLION']._serialized_end=2255
  _globals['_MSGUNSTAKEFROMGANGLIONRESPONSE']._serialized_start=2257
  _globals['_MSGUNSTAKEFROMGANGLIONRESPONSE']._serialized_end=2289
  _globals['_MSGUPDATEPATHWAY']._serialized_start=2292
  _globals['_MSGUPDATEPATHWAY']._serialized_end=2448
  _globals['_MSGUPDATEPATHWAYRESPONSE']._serialized_start=2450
  _globals['_MSGUPDATEPATHWAYRESPONSE']._serialized_end=2476
  _globals['_MSGREMOVEION']._serialized_start=2478
  _globals['_MSGREMOVEION']._serialized_end=2523
  _globals['_MSGREMOVEIONRESPONSE']._serialized_start=2525
  _globals['_MSGREMOVEIONRESPONSE']._serialized_end=2547
  _globals['_MSGREMOVEPATHWAY']._serialized_start=2549
  _globals['_MSGREMOVEPATHWAY']._serialized_end=2610
  _globals['_MSGREMOVEPATHWAYRESPONSE']._serialized_start=2612
  _globals['_MSGREMOVEPATHWAYRESPONSE']._serialized_end=2638
  _globals['_MSGSETALLOWEDIPS']._serialized_start=2640
  _globals['_MSGSETALLOWEDIPS']._serialized_end=2702
  _globals['_MSGSETALLOWEDIPSRESPONSE']._serialized_start=2704
  _globals['_MSGSETALLOWEDIPSRESPONSE']._serialized_end=2730
  _globals['_MSG']._serialized_start=2733
  _globals['_MSG']._serialized_end=4811
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/auth/v1beta1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/auth/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/auth/v1beta1/genesis.proto\x12\x13\x63osmos.auth.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"i\n\x0cGenesisState\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.auth.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12&\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=139
  _globals['_GENESISSTATE']._serialized_end=244
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/staking/v1beta1/authz.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/staking/v1beta1/authz.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/authz.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x90\x03\n\x12StakeAuthorization\x12Z\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB+\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\x12K\n\nallow_list\x18\x02 \x01(\x0b\x32\x35.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsH\x00\x12J\n\tdeny_list\x18\x03 \x01(\x0b\x32\x35.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsH\x00\x12\x45\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32).cosmos.staking.v1beta1.AuthorizationType\x1a\x1d\n\nValidators\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x03(\t:\x11\xca\xb4-\rAuthorizationB\x0c\n\nvalidators*\x9e\x01\n\x11\x41uthorizationType\x12\"\n\x1e\x41UTHORIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41UTHORIZATION_TYPE_DELEGATE\x10\x01\x12!\n\x1d\x41UTHORIZATION_TYPE_UNDELEGATE\x10\x02\x12!\n\x1d\x41UTHORIZATION_TYPE_REDELEGATE\x10\x03\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _globals['_STAKEAUTHORIZATION'].fields_by_name['max_tokens']._loaded_options = None
  _globals['_STAKEAUTHORIZATION'].fields_by_name['max_tokens']._serialized_options = b'\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _globals['_STAKEAUTHORIZATION']._loaded_options = None
  _globals['_STAKEAUTHORIZATION']._serialized_options = b'\312\264-\rAuthorization'
  _globals['_AUTHORIZATIONTYPE']._serialized_start=547
  _globals['_AUTHORIZATIONTYPE']._serialized_end=705
  _globals['_STAKEAUTHORIZATION']._serialized_start=144
  _globals['_STAKEAUTHORIZATION']._serialized_end=544
  _globals['_STAKEAUTHORIZATION_VALIDATORS']._serialized_start=482
  _globals['_STAKEAUTHORIZATION_VALIDATORS']._serialized_end=511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from neurion.fusion import params_pb2 as neurion_dot_fusion_dot_params__pb2
from neurion.fusion import task_pb2 as neurion_dot_fusion_dot_task__pb2
from neurion.fusion import creator_application_pb2 as neurion_dot_fusion_dot_creator__application__pb2
from neurion.fusion import proposed_model_pb2 as neurion_dot_fusion_dot_proposed__model__pb2
from neurion.fusion import validation_task_pb2 as neurion_dot_fusion_dot_validation__task__pb2
from neurion.fusion import dispute_validation_task_pb2 as neurion_dot_fusion_dot_dispute__validation__task__pb2
from neurion.fusion import error_code_pb2 as neurion_dot_fusion_dot_error__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aneurion/fusion/query.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bneurion/fusion/params.proto\x1a\x19neurion/fusion/task.proto\x1a(neurion/fusion/creator_application.proto\x1a#neurion/fusion/proposed_model.proto\x1a$neurion/fusion/validation_task.proto\x1a,neurion/fusion/dispute_validation_task.proto\x1a\x1fneurion/fusion/error_code.proto\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x16.neurion.fusion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"&\n\x13QueryGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"E\n\x14QueryGetTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"5\n\"QueryGetCreatorApplicationsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"h\n#QueryGetCreatorApplicationsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"+\n)QueryGetPendingCreatorApplicationsRequest\"o\n*QueryGetPendingCreatorApplicationsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x1cQueryGetModelsByRoundRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"Y\n\x1dQueryGetModelsByRoundResponse\x12\x38\n\x06models\x18\x01 \x03(\x0b\x32\x1d.neurion.fusion.ProposedModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\"+\n\x1dQueryGetValidationTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"d\n\x1eQueryGetValidationTaskResponse\x12\x42\n\x0fvalidation_task\x18\x01 \x01(\x0b\x32\x1e.neurion.fusion.ValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"U\n%QueryCanTriggerTestingForRoundRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"c\n&QueryCanTriggerTestingForRoundResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"L\n\x1cQueryCanStartNewRoundRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"Z\n\x1dQueryCanStartNewRoundResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"B\n!QueryCanRegisterAsProposerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"_\n\"QueryCanRegisterAsProposerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"C\n\"QueryCanRegisterAsValidatorRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"`\n#QueryCanRegisterAsValidatorResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"7\n\x16QueryIsProposerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"T\n\x17QueryIsProposerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"8\n\x17QueryIsValidatorRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"U\n\x18QueryIsValidatorResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"K\n\x1bQueryCanProposeModelRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"Y\n\x1cQueryCanProposeModelResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"T\n$QueryCanRequestValidationTaskRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"b\n%QueryCanRequestValidationTaskResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"F\n%QueryGetPendingValidationTasksRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"m\n&QueryGetPendingValidationTasksResponse\x12\x43\n\x10validation_tasks\x18\x01 \x03(\x0b\x32\x1e.neurion.fusion.ValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"<\n\x18QueryCanTerminateRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"V\n\x19QueryCanTerminateResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"3\n#QueryGetScoreDisputeFromUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"z\n$QueryGetScoreDisputeFromUserResponse\x12R\n\x18\x64ispute_validation_tasks\x18\x01 \x03(\x0b\x32%.neurion.fusion.DisputeValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xbe\x1a\n\x05Query\x12q\n\x06Params\x12\".neurion.fusion.QueryParamsRequest\x1a#.neurion.fusion.QueryParamsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/neurion/fusion/params\x12\x80\x01\n\x07GetTask\x12#.neurion.fusion.QueryGetTaskRequest\x1a$.neurion.fusion.QueryGetTaskResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/fusion/get_task/{task_id}\x12\xa0\x01\n\rGetTaskReward\x12).neurion.fusion.QueryGetTaskRewardRequest\x1a*.neurion.fusion.QueryGetTaskRewardResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_task_reward/{task_id}/{user}\x12\xbd\x01\n\x16GetCreatorApplications\x12\x32.neurion.fusion.QueryGetCreatorApplicationsRequest\x1a\x33.neurion.fusion.QueryGetCreatorApplicationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/fusion/get_creator_applications/{creator}\x12\xd0\x01\n\x1dGetPendingCreatorApplications\x12\x39.neurion.fusion.QueryGetPendingCreatorApplicationsRequest\x1a:.neurion.fusion.QueryGetPendingCreatorApplicationsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_pending_creator_applications\x12\xae\x01\n\x10GetModelsByRound\x12,.neurion.fusion.QueryGetModelsByRoundRequest\x1a-.neurion.fusion.QueryGetModelsByRoundResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/neurion/fusion/get_models_by_round/{task_id}/{round}\x12\x9c\x01\n\x0cGetTaskStake\x12(.neurion.fusion.QueryGetTaskStakeRequest\x1a).neurion.fusion.QueryGetTaskStakeResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//neurion/fusion/get_task_stake/{task_id}/{user}\x12\xa4\x01\n\x11GetValidationTask\x12-.neurion.fusion.QueryGetValidationTaskRequest\x1a..neurion.fusion.QueryGetValidationTaskResponse\"0\x82\xd3\xe4\x93\x02*\x12(/neurion/fusion/get_validation_task/{id}\x12\xda\x01\n\x19\x43\x61nTriggerTestingForRound\x12\x35.neurion.fusion.QueryCanTriggerTestingForRoundRequest\x1a\x36.neurion.fusion.QueryCanTriggerTestingForRoundResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/neurion/fusion/can_trigger_testing_for_round/{user}/{task_id}/{round}\x12\xb5\x01\n\x10\x43\x61nStartNewRound\x12,.neurion.fusion.QueryCanStartNewRoundRequest\x1a-.neurion.fusion.QueryCanStartNewRoundResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/fusion/can_start_new_round/{user}/{task_id}/{round}\x12\xc1\x01\n\x15\x43\x61nRegisterAsProposer\x12\x31.neurion.fusion.QueryCanRegisterAsProposerRequest\x1a\x32.neurion.fusion.QueryCanRegisterAsProposerResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/neurion/fusion/can_register_as_proposer/{user}/{task_id}\x12\xc5\x01\n\x16\x43\x61nRegisterAsValidator\x12\x32.neurion.fusion.QueryCanRegisterAsValidatorRequest\x1a\x33.neurion.fusion.QueryCanRegisterAsValidatorResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/fusion/can_register_as_validator/{user}/{task_id}\x12\x93\x01\n\nIsProposer\x12&.neurion.fusion.QueryIsProposerRequest\x1a\'.neurion.fusion.QueryIsProposerResponse\"4\x82\xd3\xe4\x93\x02.\x12,/neurion/fusion/is_proposer/{user}/{task_id}\x12\x97\x01\n\x0bIsValidator\x12\'.neurion.fusion.QueryIsValidatorRequest\x1a(.neurion.fusion.QueryIsValidatorResponse\"5\x82\xd3\xe4\x93\x02/\x12-/neurion/fusion/is_validator/{user}/{task_id}\x12\xb0\x01\n\x0f\x43\x61nProposeModel\x12+.neurion.fusion.QueryCanProposeModelRequest\x1a,.neurion.fusion.QueryCanProposeModelResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/fusion/can_propose_model/{user}/{task_id}/{round}\x12\xd5\x01\n\x18\x43\x61nRequestValidationTask\x12\x34.neurion.fusion.QueryCanRequestValidationTaskRequest\x1a\x35.neurion.fusion.QueryCanRequestValidationTaskResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/fusion/can_request_validation_task/{user}/{task_id}/{round}\x12\xd1\x01\n\x19GetPendingValidationTasks\x12\x35.neurion.fusion.QueryGetPendingValidationTasksRequest\x1a\x36.neurion.fusion.QueryGetPendingValidationTasksResponse\"E\x82\xd3\xe4\x93\x02?\x12=/neurion/fusion/get_pending_validation_tasks/{user}/{task_id}\x12\x9e\x01\n\x0c\x43\x61nTerminate\x12(.neurion.fusion.QueryCanTerminateRequest\x1a).neurion.fusion.QueryCanTerminateResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/fusion/can_terminate/{creator}/{task_id}\x12\xc0\x01\n\x17GetScoreDisputeFromUser\x12\x33.neurion.fusion.QueryGetScoreDisputeFromUserRequest\x1a\x34.neurion.fusion.QueryGetScoreDisputeFromUserResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/fusion/get_score_dispute_from_user/{user}B\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._loaded_options = None
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._loaded_options = None
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE'].fields_by_name['validation_tasks']._loaded_options = None
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE'].fields_by_name['validation_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_validation_tasks']._loaded_options = None
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_validation_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\030\022\026/neurion/fusion/params'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/fusion/get_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._serialized_options = b'\202\323\344\223\0024\0222/neurion/fusion/get_creator_applications/{creator}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._serialized_options = b'\202\323\344\223\0027\0225/neurion/fusion/get_models_by_round/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\0021\022//neurion/fusion/get_task_stake/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetValidationTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetValidationTask']._serialized_options = b'\202\323\344\223\002*\022(/neurion/fusion/get_validation_task/{id}'
  _globals['_QUERY'].methods_by_name['CanTriggerTestingForRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTriggerTestingForRound']._serialized_options = b'\202\323\344\223\002H\022F/neurion/fusion/can_trigger_testing_for_round/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['CanStartNewRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanStartNewRound']._serialized_options = b'\202\323\344\223\002>\022</neurion/fusion/can_start_new_round/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsProposer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsProposer']._serialized_options = b'\202\323\344\223\002;\0229/neurion/fusion/can_register_as_proposer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsValidator']._serialized_options = b'\202\323\344\223\002<\022:/neurion/fusion/can_register_as_validator/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsProposer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsProposer']._serialized_options = b'\202\323\344\223\002.\022,/neurion/fusion/is_proposer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsValidator']._serialized_options = b'\202\323\344\223\002/\022-/neurion/fusion/is_validator/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanProposeModel']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanProposeModel']._serialized_options = b'\202\323\344\223\002<\022:/neurion/fusion/can_propose_model/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['CanRequestValidationTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRequestValidationTask']._serialized_options = b'\202\323\344\223\002F\022D/neurion/fusion/can_request_validation_task/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['GetPendingValidationTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingValidationTasks']._serialized_options = b'\202\323\344\223\002?\022=/neurion/fusion/get_pending_validation_tasks/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTerminate']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTerminate']._serialized_options = b'\202\323\344\223\0023\0221/neurion/fusion/can_terminate/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._serialized_options = b'\202\323\344\223\0024\0222/neurion/fusion/get_score_dispute_from_user/{user}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=369
  _globals['_QUERYPARAMSREQUEST']._serialized_end=389
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=391
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=463
  _globals['_QUERYGETTASKREQUEST']._serialized_start=465
  _globals['_QUERYGETTASKREQUEST']._serialized_end=503
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=505
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=574
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=576
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=634
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=636
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=680
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_start=682
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_end=735
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_start=737
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_end=841
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=843
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=886
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=888
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=999
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_start=1001
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_end=1063
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_start=1065
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_end=1154
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=1156
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=1213
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=1215
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=1257
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_start=1259
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_end=1302
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_start=1304
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_end=1404
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDREQUEST']._serialized_start=1406
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDREQUEST']._serialized_end=1491
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDRESPONSE']._serialized_start=1493
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDRESPONSE']._serialized_end=1592
  _globals['_QUERYCANSTARTNEWROUNDREQUEST']._serialized_start=1594
  _globals['_QUERYCANSTARTNEWROUNDREQUEST']._serialized_end=1670
  _globals['_QUERYCANSTARTNEWROUNDRESPONSE']._serialized_start=1672
  _globals['_QUERYCANSTARTNEWROUNDRESPONSE']._serialized_end=1762
  _globals['_QUERYCANREGISTERASPROPOSERREQUEST']._serialized_start=1764
  _globals['_QUERYCANREGISTERASPROPOSERREQUEST']._serialized_end=1830
  _globals['_QUERYCANREGISTERASPROPOSERRESPONSE']._serialized_start=1832
  _globals['_QUERYCANREGISTERASPROPOSERRESPONSE']._serialized_end=1927
  _globals['_QUERYCANREGISTERASVALIDATORREQUEST']._serialized_start=1929
  _globals['_QUERYCANREGISTERASVALIDATORREQUEST']._serialized_end=1996
  _globals['_QUERYCANREGISTERASVALIDATORRESPONSE']._serialized_start=1998
  _globals['_QUERYCANREGISTERASVALIDATORRESPONSE']._serialized_end=2094
  _globals['_QUERYISPROPOSERREQUEST']._serialized_start=2096
  _globals['_QUERYISPROPOSERREQUEST']._serialized_end=2151
  _globals['_QUERYISPROPOSERRESPONSE']._serialized_start=2153
  _globals['_QUERYISPROPOSERRESPONSE']._serialized_end=2237
  _globals['_QUERYISVALIDATORREQUEST']._serialized_start=2239
  _globals['_QUERYISVALIDATORREQUEST']._serialized_end=2295
  _globals['_QUERYISVALIDATORRESPONSE']._serialized_start=2297
  _globals['_QUERYISVALIDATORRESPONSE']._serialized_end=2382
  _globals['_QUERYCANPROPOSEMODELREQUEST']._serialized_start=2384
  _globals['_QUERYCANPROPOSEMODELREQUEST']._serialized_end=2459
  _globals['_QUERYCANPROPOSEMODELRESPONSE']._serialized_start=2461
  _globals['_QUERYCANPROPOSEMODELRESPONSE']._serialized_end=2550
  _globals['_QUERYCANREQUESTVALIDATIONTASKREQUEST']._serialized_start=2552
  _globals['_QUERYCANREQUESTVALIDATIONTASKREQUEST']._serialized_end=2636
  _globals['_QUERYCANREQUESTVALIDATIONTASKRESPONSE']._serialized_start=2638
  _globals['_QUERYCANREQUESTVALIDATIONTASKRESPONSE']._serialized_end=2736
  _globals['_QUERYGETPENDINGVALIDATIONTASKSREQUEST']._serialized_start=2738
  _globals['_QUERYGETPENDINGVALIDATIONTASKSREQUEST']._serialized_end=2808
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE']._serialized_start=2810
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE']._serialized_end=2919
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_start=2921
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_end=2981
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_start=2983
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_end=3069
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_start=3071
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_end=3122
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_start=3124
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_end=3246
  _globals['_QUERY']._serialized_start=3249
  _globals['_QUERY']._serialized_end=6639
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from ibc.applications.transfer.v1 import query_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in ibc/applications/transfer/v1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query provides defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DenomTrace = channel.unary_unary(
                '/ibc.applications.transfer.v1.Query/DenomTrace',
                request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceResponse.FromString,
                _registered_method=True)
        self.DenomTraces = channel.unary_unary(
                '/ibc.applications.transfer.v1.Query/DenomTraces',
                request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/ibc.applications.transfer.v1.Query/Params',
                request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.DenomHash = channel.unary_unary(
                '/ibc.applications.transfer.v1.Query/DenomHash',
                request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query provides defines the gRPC querier service.
    """

    def DenomTrace(self, request, context):
        """DenomTrace queries a denomination trace information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomTraces(self, request, context):
        """DenomTraces queries all denomination traces.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries all parameters of the ibc-transfer module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomHash(self, request, context):
        """DenomHash queries a denomination hash information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DenomTrace': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomTrace,
                    request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceResponse.SerializeToString,
            ),
            'DenomTraces': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomTraces,
                    request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'DenomHash': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomHash,
                    request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.applications.transfer.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ibc.applications.transfer.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query provides defines the gRPC querier service.
    """

    @staticmethod
    def DenomTrace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.applications.transfer.v1.Query/DenomTrace',
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceRequest.SerializeToString,
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomTraces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.applications.transfer.v1.Query/DenomTraces',
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesRequest.SerializeToString,
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.applications.transfer.v1.Query/Params',
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.applications.transfer.v1.Query/DenomHash',
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashRequest.SerializeToString,
            ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Snapshot(_message.Message):
    __slots__ = ("height", "format", "chunks", "hash", "metadata")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunks: int
    hash: bytes
    metadata: Metadata
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunks: _Optional[int] = ..., hash: _Optional[bytes] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("chunk_hashes",)
    CHUNK_HASHES_FIELD_NUMBER: _ClassVar[int]
    chunk_hashes: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, chunk_hashes: _Optional[_Iterable[bytes]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/crypto/v1/proof.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/crypto/v1/proof.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ometbft/crypto/v1/proof.proto\x12\x12\x63ometbft.crypto.v1\x1a\x14gogoproto/gogo.proto\"G\n\x05Proof\x12\r\n\x05total\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x11\n\tleaf_hash\x18\x03 \x01(\x0c\x12\r\n\x05\x61unts\x18\x04 \x03(\x0c\"@\n\x07ValueOp\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12(\n\x05proof\x18\x02 \x01(\x0b\x32\x19.cometbft.crypto.v1.Proof\"6\n\x08\x44ominoOp\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\x12\x0e\n\x06output\x18\x03 \x01(\t\"2\n\x07ProofOp\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\":\n\x08ProofOps\x12.\n\x03ops\x18\x01 \x03(\x0b\x32\x1b.cometbft.crypto.v1.ProofOpB\x04\xc8\xde\x1f\x00\x42\x35Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.crypto.v1.proof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1'
  _globals['_PROOFOPS'].fields_by_name['ops']._loaded_options = None
  _globals['_PROOFOPS'].fields_by_name['ops']._serialized_options = b'\310\336\037\000'
  _globals['_PROOF']._serialized_start=76
  _globals['_PROOF']._serialized_end=147
  _globals['_VALUEOP']._serialized_start=149
  _globals['_VALUEOP']._serialized_end=213
  _globals['_DOMINOOP']._serialized_start=215
  _globals['_DOMINOOP']._serialized_end=269
  _globals['_PROOFOP']._serialized_start=271
  _globals['_PROOFOP']._serialized_end=321
  _globals['_PROOFOPS']._serialized_start=323
  _globals['_PROOFOPS']._serialized_end=381
# @@protoc_insertion_point(module_scope)



from enum import Enum

from neurionpy.crypto.address import Address
from neurionpy.protos.cosmos.base.v1beta1.coin_pb2 import Coin
from neurionpy.protos.cosmos.staking.v1beta1.tx_pb2 import (
    MsgBeginRedelegate,
    MsgDelegate,
    MsgUndelegate,
)


class ValidatorStatus(Enum):
    """Validator status."""

    UNSPECIFIED = "BOND_STATUS_UNSPECIFIED"
    BONDED = "BOND_STATUS_BONDED"
    UNBONDING = "BOND_STATUS_UNBONDING"
    UNBONDED = "BOND_STATUS_UNBONDED"

    @classmethod
    def from_proto(cls, value: int) -> "ValidatorStatus":
        """Get the validator status from proto.

        :param value: value
        :raises RuntimeError: Unable to decode validator status
        :return: Validator status
        """
        if value == 0:
            return cls.UNSPECIFIED
        if value == 1:
            return cls.UNBONDED
        if value == 2:
            return cls.UNBONDING
        if value == 3:
            return cls.BONDED
        raise RuntimeError(f"Unable to decode validator status: {value}")


def create_delegate_msg(
    delegator: Address, validator: Address, amount: int, denom: str
) -> MsgDelegate:
    """Create delegate message.

    :param delegator: delegator
    :param validator: validator
    :param amount: amount
    :param denom: denom
    :return: Delegate message
    """
    return MsgDelegate(
        delegator_address=str(delegator),
        validator_address=str(validator),
        amount=Coin(
            amount=str(amount),
            denom=denom,
        ),
    )


def create_redelegate_msg(
    delegator_address: Address,
    validator_src_address: Address,
    validator_dst_address: Address,
    amount: int,
    denom: str,
) -> MsgBeginRedelegate:
    """Create redelegate message.

    :param delegator_address: delegator address
    :param validator_src_address: source validation address
    :param validator_dst_address: destination validation address
    :param amount: amount
    :param denom: denom
    :return: Redelegate message
    """
    return MsgBeginRedelegate(
        delegator_address=str(delegator_address),
        validator_src_address=str(validator_src_address),
        validator_dst_address=str(validator_dst_address),
        amount=Coin(
            amount=str(amount),
            denom=str(denom),
        ),
    )


def create_undelegate_msg(
    delegator_address: Address, validator_address: Address, amount: int, denom: str
) -> MsgUndelegate:
    """Create undelegate message.

    :param delegator_address: delegator address
    :param validator_address: validator address
    :param amount: amount
    :param denom: denom
    :return: Undelegate message
    """
    return MsgUndelegate(
        delegator_address=str(delegator_address),
        validator_address=str(validator_address),
        amount=Coin(
            amount=str(amount),
            denom=str(denom),
        ),
    )



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.capability.v1beta1 import capability_pb2 as _capability_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisOwners(_message.Message):
    __slots__ = ("index", "index_owners")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    INDEX_OWNERS_FIELD_NUMBER: _ClassVar[int]
    index: int
    index_owners: _capability_pb2.CapabilityOwners
    def __init__(self, index: _Optional[int] = ..., index_owners: _Optional[_Union[_capability_pb2.CapabilityOwners, _Mapping]] = ...) -> None: ...

class GenesisState(_message.Message):
    __slots__ = ("index", "owners")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    index: int
    owners: _containers.RepeatedCompositeFieldContainer[GenesisOwners]
    def __init__(self, index: _Optional[int] = ..., owners: _Optional[_Iterable[_Union[GenesisOwners, _Mapping]]] = ...) -> None: ...



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.neurion.ganglion.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryIonByIonAddressRequest, QueryIonByIonAddressResponse,
    QueryIonByCreatorRequest, QueryIonByCreatorResponse,
    QueryGetValidatorsRequest, QueryGetValidatorsResponse,
    QueryIonsByInputSchemaHashRequest, QueryIonsByInputSchemaHashResponse,
    QueryGetPathwayRequest, QueryGetPathwayResponse,
    QueryListPathwaysRequest, QueryListPathwaysResponse,
    QueryListIonsByAddressesRequest, QueryListIonsByAddressesResponse,
    QueryUserPathwayStakeRequest, QueryUserPathwayStakeResponse,
    QueryGetUserRewardRequest, QueryGetUserRewardResponse,
    QueryGetProtocolFeeRequest, QueryGetProtocolFeeResponse,
    QueryPathwaysUsingIonRequest, QueryPathwaysUsingIonResponse,
    QueryIonsByReportsRequest, QueryIonsByReportsResponse,
    QueryListAllPathwaysRequest, QueryListAllPathwaysResponse,
    QueryGetRewardRequest, QueryGetRewardResponse,
    QueryGetStakeRequest, QueryGetStakeResponse,
    QueryGetIonRequest, QueryGetIonResponse,
    QueryGetPathwayUnstakeInitiatedUsersRequest, QueryGetPathwayUnstakeInitiatedUsersResponse,
    QueryGetStakerRewardRequest, QueryGetStakerRewardResponse,
    QueryGetAvailableIonsRequest, QueryGetAvailableIonsResponse, QueryValidateIonChainRequest,
    QueryValidateIonChainResponse, QueryGetAllowedIpsRequest, QueryGetAllowedIpsResponse
)
from neurionpy.ganglion.interface import GanglionQuery


class GanglionRestClient(GanglionQuery):
    """Ganglion REST client implementing all query endpoints."""
    API_URL = "/neurion/ganglion"

    def __init__(self, rest_api: RestClient):
        """
        Initialize the Ganglion REST client.

        :param rest_api: RestClient instance for making HTTP GET requests.
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """Query module parameters."""
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())

    def IonByIonAddress(self, request: QueryIonByIonAddressRequest) -> QueryIonByIonAddressResponse:
        """Query an Ion by its ion_address."""
        response = self._rest_api.get(f"{self.API_URL}/ion_by_ion_address/{request.ion_address}")
        return Parse(response, QueryIonByIonAddressResponse())

    def IonByCreator(self, request: QueryIonByCreatorRequest) -> QueryIonByCreatorResponse:
        """Query an Ion by its creator."""
        response = self._rest_api.get(f"{self.API_URL}/ion_by_creator/{request.creator}")
        return Parse(response, QueryIonByCreatorResponse())

    def GetValidators(self, request: QueryGetValidatorsRequest) -> QueryGetValidatorsResponse:
        """Query the list of validators."""
        response = self._rest_api.get(f"{self.API_URL}/get_validators")
        return Parse(response, QueryGetValidatorsResponse())

    def IonsByInputSchemaHash(self, request: QueryIonsByInputSchemaHashRequest) -> QueryIonsByInputSchemaHashResponse:
        """Query Ions by input_schema_hash with pagination."""
        response = self._rest_api.get(
            f"{self.API_URL}/ions_by_input_schema_hash/{request.input_schema_hash}/{request.user}/{request.offset}/{request.limit}"
        )
        return Parse(response, QueryIonsByInputSchemaHashResponse())

    def GetPathway(self, request: QueryGetPathwayRequest) -> QueryGetPathwayResponse:
        """Query a pathway by its ID."""
        response = self._rest_api.get(f"{self.API_URL}/get_pathway/{request.id}")
        return Parse(response, QueryGetPathwayResponse())

    def ListPathways(self, request: QueryListPathwaysRequest) -> QueryListPathwaysResponse:
        """List pathways for a creator with pagination."""
        response = self._rest_api.get(
            f"{self.API_URL}/list_pathways/{request.creator}/{request.offset}/{request.limit}"
        )
        return Parse(response, QueryListPathwaysResponse())

    def ListIonsByAddresses(self, request: QueryListIonsByAddressesRequest) -> QueryListIonsByAddressesResponse:
        """List Ions by a list of ion addresses."""
        addresses = ",".join(request.ion_addresses)
        response = self._rest_api.get(f"{self.API_URL}/list_ions_by_addresses/{addresses}")
        return Parse(response, QueryListIonsByAddressesResponse())

    def UserPathwayStake(self, request: QueryUserPathwayStakeRequest) -> QueryUserPathwayStakeResponse:
        """Query pathway stake for a given pathway and user."""
        response = self._rest_api.get(f"{self.API_URL}/user_pathway_stake/{request.id}/{request.user}")
        return Parse(response, QueryUserPathwayStakeResponse())

    def GetUserReward(self, request: QueryGetUserRewardRequest) -> QueryGetUserRewardResponse:
        """Query user reward."""
        response = self._rest_api.get(f"{self.API_URL}/get_user_reward/{request.user}")
        return Parse(response, QueryGetUserRewardResponse())

    def GetProtocolFee(self, request: QueryGetProtocolFeeRequest) -> QueryGetProtocolFeeResponse:
        """Query the protocol fee."""
        response = self._rest_api.get(f"{self.API_URL}/get_protocol_fee")
        return Parse(response, QueryGetProtocolFeeResponse())

    def PathwaysUsingIon(self, request: QueryPathwaysUsingIonRequest) -> QueryPathwaysUsingIonResponse:
        """Query pathways using a given ion."""
        response = self._rest_api.get(f"{self.API_URL}/pathways_using_ion/{request.ion_address}")
        return Parse(response, QueryPathwaysUsingIonResponse())

    def IonsByReports(self, request: QueryIonsByReportsRequest) -> QueryIonsByReportsResponse:
        """Query ions by reports with pagination."""
        response = self._rest_api.get(f"{self.API_URL}/ions_by_reports/{request.offset}/{request.limit}")
        return Parse(response, QueryIonsByReportsResponse())

    def ListAllPathways(self, request: QueryListAllPathwaysRequest) -> QueryListAllPathwaysResponse:
        """List all pathways with pagination."""
        response = self._rest_api.get(f"{self.API_URL}/list_all_pathways/{request.offset}/{request.limit}")
        return Parse(response, QueryListAllPathwaysResponse())

    def GetReward(self, request: QueryGetRewardRequest) -> QueryGetRewardResponse:
        """Query reward for a given user."""
        response = self._rest_api.get(f"{self.API_URL}/get_reward/{request.user}")
        return Parse(response, QueryGetRewardResponse())

    def GetStake(self, request: QueryGetStakeRequest) -> QueryGetStakeResponse:
        """Query stake for a given user."""
        response = self._rest_api.get(f"{self.API_URL}/get_stake/{request.user}")
        return Parse(response, QueryGetStakeResponse())

    def GetIon(self, request: QueryGetIonRequest) -> QueryGetIonResponse:
        """Query an Ion by its ID."""
        response = self._rest_api.get(f"{self.API_URL}/get_ion/{request.id}")
        return Parse(response, QueryGetIonResponse())

    def GetPathwayUnstakeInitiatedUsers(self, request: QueryGetPathwayUnstakeInitiatedUsersRequest) -> QueryGetPathwayUnstakeInitiatedUsersResponse:
        """Query pathway unstake initiated users."""
        response = self._rest_api.get(f"{self.API_URL}/get_pathway_unstake_initiated_users")
        return Parse(response, QueryGetPathwayUnstakeInitiatedUsersResponse())

    def GetStakerReward(self, request: QueryGetStakerRewardRequest) -> QueryGetStakerRewardResponse:
        """Query staker reward."""
        response = self._rest_api.get(f"{self.API_URL}/get_staker_reward")
        return Parse(response, QueryGetStakerRewardResponse())

    def GetAvailableIons(self, request: QueryGetAvailableIonsRequest) -> QueryGetAvailableIonsResponse:
        """Query available Ions with pagination."""
        response = self._rest_api.get(f"{self.API_URL}/get_available_ions/{request.user}/{request.offset}/{request.limit}")
        return Parse(response, QueryGetAvailableIonsResponse())

    def ValidateIonChain(self, request: QueryValidateIonChainRequest) -> QueryValidateIonChainResponse:
        """Validate the Ion chain."""
        response = self._rest_api.get(f"{self.API_URL}/validate_ion_chain/{request.ion1}/{request.ion2}/{request.field_map_base64}")
        return Parse(response, QueryValidateIonChainResponse())

    def GetAllowedIps(self, request: QueryGetAllowedIpsRequest) -> QueryGetAllowedIpsResponse:
        """Get allowed IPs."""
        response = self._rest_api.get(f"{self.API_URL}/get_allowed_ips")
        return Parse(response, QueryGetAllowedIpsResponse())


from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetVersionRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetVersionResponse(_message.Message):
    __slots__ = ("node", "abci", "p2p", "block")
    NODE_FIELD_NUMBER: _ClassVar[int]
    ABCI_FIELD_NUMBER: _ClassVar[int]
    P2P_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    node: str
    abci: str
    p2p: int
    block: int
    def __init__(self, node: _Optional[str] = ..., abci: _Optional[str] = ..., p2p: _Optional[int] = ..., block: _Optional[int] = ...) -> None: ...



import base64
import gzip
from typing import List


def decompress_words(encoded_data: str) -> List[str]:
    """
    Decode base64 encoded and compressed list of words.

    :param encoded_data: str The base64 encoded compressed data.

    :return: List[str] The decoded and decompressed list of words.
    """
    decoded_data = base64.b64decode(encoded_data)
    decompressed_data = gzip.decompress(decoded_data).decode()
    return decompressed_data.split(",")


ENGLISH_COMPRESSED = (
    "H4sIAJG1kWQC/y2bCZasKhBEN1SbckClS8HPUHb16n/c4J0+FYmKCEmSE/Q0T2nN6TXN8YztK3oGQe4N/FCuIXFRc5k"
    "hrUyLr3tZRXpVnWUJtULi6srLkvug4/ERA03psSD32uKiwn89Fu6W7Jep3yJ9WVouYBmttj6dr2mdbtVYV35xcXE8X3"
    "/UoMgVwX6CnyktARohoeSZL27bFAsk0/WtTPRnn6I+uQd+9HkvQeUjTHoWr5ffiOXORc9ihTvnVHT/nDu45COrd2fg+"
    "RmD2jq5PsMXzI/wynTwzImX72MSFrVPhZoFLegb5zN9NZpraqEX6F9Mu2geaH5eYqe6labzS4tpOWBUWqJ7nnbaSTt9"
    "THtR8ylesC69fSupkcUFMzTldviF+pi0kNIEjf91av3GgEAk/e6J0d35zDtXd5gKhFbvu1hM7hLVZlkOwPOrIQK0WXZ"
    "ahGvlYgDlot/lUmNFneJOofvQwMhKiR9fwT++XVrYLCKlRVdoTy7v11T53YEntU6e/FqD0fVq7Zcaqu241I92nKHpsm"
    "V1pbVpeUMCHWgttr7y7J+A93/C2Ffkqu8WMs9Cb2Z7bxnolyp9QrEIffIyrRmKaD3TO4DFqME+oWa682xdzHreeqRqv"
    "7G+5mn+CpYjnGpbBX16nla1OU+7fqcFekbeEhUlY/N0zTmLJP1BUuBN/8JJpWLZnmEq1SsNVE2N8C0ezRqrpnAO+iyY"
    "gK45n8MysXBF6e4cwibQqqG802Q4NGRIFO/mcHp9i2q6hGo6JLeZwha5qoAYS9sNcRd5QqClb6aJuHwX+hIpvyn47pC"
    "4ORYuSlOTcbx+MndCzZjwMiYP6pz42BkmnqMg5tNtnTkbq6YA6gGe3UCDvar1zIQI1ULW+pyzhHrO1yzQ4hV0tZfzG+"
    "AzUiT0JhfWqgjyOqPO5twQsnksuTn/6qf2JFruZPHESOZXkPrFDEUtgOGPi8gYS7QUlMgklLgfvO7PlVh5nqVtz0jhD"
    "UNLTn458/ky1rjowyOPsc/o+LmvDLCrcTXYpRpPyVKPp77fzxl4A6cfp9WviMNqTIqfD/WyjysYAV96jckM75WWx0T1"
    "r/Hv77VM88wiEdXgF1uaBe1eRXz/DUiyBZfg0qKC3AJekNoDl2Ci3i/oND/JvJk+E02lr+/d/z5wx+b37jb5s4Xf7Cq"
    "aa8GewVvjFCm0WihWXha/BDFRpTa3V7ubo4oazjt0oVoLe/brbVTsTNVYSEIrk4VJXoJMreZP4wjUDxfaewmpwgmVu+"
    "9KFE7I6PaBHRJqUoTX7dYO60yRXMEbhouWcbMa1bJs2Q0uvBuC70uYBB7uweqUiV4QH0w1j5AD4ZUCNTJmVCT7XUmYl"
    "Mhy9AW7IppouBe9HXf4G2VILjoYC4t6iS3+0TYOxhI/WlPLiW0V3kCJ2xf6AJTQRUIpeOGHUZ2sheW0oRPZNlDrUujO"
    "nJGWsisxJ6e7ekr8wb6CD4123unIlFa8GXZ2z1+eBsKMLC3boVIvS962AKHbmbnIWhQLT1HVQiyAFKWkmmqXYcNfEKV"
    "v+TIz8nVjTNU0swpdu5tJW5RpFN3t0KiQRvupRtSLCq1kvp4+EXWyoIEE3JIxpsZNwwWJQUsL+KD0vtvxkKSPuNc9St"
    "kxpj53bLhIqSbVwzPD8zfLUi4oLJD1L7I18AKSb7BAymQ+luk5wT81LOGlUsB2igTaCJpeVBoLrUTYJAV2g7gL8gIpo"
    "zuF7qWUluat9CUyrtKDMdLV0i+v7tKTa3b3gw/LMaJ2n/VU7kCHG/3mN5T70kvMLLQu7iBM/d8K64W1qYa8tCQb0p9L"
    "hwe2TKsU8yqvbKco8VltkNfhdK2TNfIKO1YvfN+UwK2S55WVvAaZ2wDRqEUWTJdIuGbqBlxnyIkUieYyqsPKSsG1Nmk"
    "JLrZRa6NxO6xrOP2lM35c8cK0iERXT9E9SPadRKlpn04kuOKda/SlFowQL0CihxO2hqopml0IfqXGPUHewI1iEpWE8o"
    "p4yZcagrdq6Z6aVVH0hwgitUa52JKO1X2KKIoVqtlbXS3qOzyRnKxa6Awn7lbiogkdssYzXPLn1mifRyTL96NggRcB6"
    "nDlVRgircJgZWSWYhVvKnTYcBVus1AsGlMLJ2nn45mJn1x890/yvWaHKCLdynuVylmlFoBbPpHoNZkkz2KW4eSt5JcM"
    "dCR3hHjFf169toS7pE+E0Wl1sTJEHwErakQ8q/QldSMflOC9wRtwQ3Bc60OgT0pHC6Qo147E9CGn+LKr1d7qmZYfur3"
    "Wr7S2vhcmRFqovsnRlycpTIBkQxyMvqMWBCrJLAiGoyaasrz6gMvixR/UA1gQNmvEsO+vYB8mRHsm4ZzlMoVzdVmzV+"
    "jBGXbFIVCzV1RR0yh8JjgvOafRU1zUAppkKETw2ESksrgbMIPhyja84brPzNM7E+yIatgKTeC/iISGZRBwc8Rg0YxGl"
    "PvKYCRjjC1tloCQdpSACGswpMPSEtIP7aeTFRYUae3iVdJgTBAN7HuhIrqBpTguCm95nejyljRK2MJ/+BhCzSo+kH70"
    "pviZVKRHJF9T7ZSuqFgrdOJ1RUBfMLhHkmN4pM/hOIUmC6+hIc1+jBnWinxTzKckJ/yaD7/SbnDl1zG9yPAyVDDLf2U"
    "vV1Mcm/AbrCNFyxJ945iQLtE4M/+/0Y2ZLb++kRHq8HujoUSCP3qbHb9aglo2otlt3WX0wSGaCLz4Bn54tK9twkcW0X"
    "gEUvdf0ZWLKGkRSmI3PEpB5fZlQII3Yuoqkvgt3EgNgd6IU7dp2IFtohl0jxB5FYkEs5tjzU2BXoEtW5hsajZ1rKPKt"
    "iCJ5rXATcW8Aq4Uj3ODGdg0Q/HjOqzEzY7OJiu5RUzCFkcAukWtDuHu9uGm4AKaazG5GxGObYJgH7fRclv0Owwo4qZv"
    "0oWu7mdcN3vsW/x9bacCzc2xlJAKJ4M/GaII4zi9cjd8re3MforHJXQVL63t7IrhNodTG3zO0lubFKW+Ii254UZtmRF"
    "lZ0c2wjKBGvPyIsqsviAw2Qjy0RxoL9FOW8Vh8yZXwW3Zi9ucRtgUZ23SoeZS8VCKlhE6RAV6pDCKeqhBHtIjubM8xk"
    "vaHCcJcVc3+Rq6hdux9cRPdnOTm2txw0nfuid9nxxEOdjeFan/fiF27nf6sMvLlV+M1hCZ/1FiKBE5thDruV3xi37Ub"
    "tSxxO3yJ7hQULejijR/olH8FCm+Sbwh0hGAXdxzpw4GtEfU5o692OOORt+HgOxRBmfjsqg9DMeuYBpANEWKUbKxn9g/"
    "4XVXaJ6N8o6EDPHMfltzuRNO7wjGntcVwdqZ6Z0p3h08KEKS1ZpE6y2+7syhhot9FjdgvnyDGaAXjpKFDKGg4XbHysI"
    "PboDMO58q5BF2hcmAghchd/PiCZAveYPqXSF7s3eER0uYhrqHpqCX+3IxxBfN9P69XseE9nLUpaBrE1yyKBCL24HyUs"
    "Qlt/sgmuRO4U6RkAk/yDDBl/Mkx/S8BX+uQoQvOKWaDmwq+FEz2MxD8ngM+3gELQ/wCr64BUm/optxRXgO1RNIux1ou"
    "0OMPFjvh3QtE3PkeQYXfI+DiRAEIOKVHmP9HQQsR06uk6lzc63pOLJNzGFTKGkagbTF6pAjR7HzGLV1KKw6kNOjy/ME"
    "sawiNKCVqUgASlLyYBYULa6uUHwHLvQ6m6lfMh4vPMFIEkwzNL2cViZIjLwlL5Agh5HrJ1fB1Ios2kGPV7Tti5oz/GV"
    "R9IckGAsnkn1zZC5FO8YhEkkIbN5E4YvIcL+lX8MvGO3NqIDKE5Gt0whiwnpATlLTEVfhEjnQ9iIBkZRKbvi8Mf0EV/"
    "rpfvUaLeLJCjMZABXkggtJkVOnEm6JjBcJCyE2mqINEycZ8OjwL5A+FbLgM8qf6I8MSx8LjK0n/JbHcboDtWrxqpb6/"
    "UF8fkaq6mdixYjw+/t7/Uh0MZyiCTyl43/CI3H4ybN+WrE/OBU/Eg6ECrfohyyTkEn9Ifb+6c5Si0Sx8YcEgpP4b7ka"
    "U8n59WZNC26BjGOHfl9vkgBvSYd+ydeJctrlbotq/t/is34La+XNkN/kCyk/8fVOMmLvFDcQwyV8Xqf0jX4agFC9kRr"
    "EGT3Jz5+kpE7CPfFKfNi5ulvmuviiuWrTqE/iPjDheMtsTi8yGidRoKBiTBRguL5CiFN6gHKYNkDrTai5wQdGf59BOl"
    "vC/RoCLsRwnSHW8ZSUwjlupV26RKQK8o2SwYv1c+fgSKGoBYVYArkWUp2iBTdF4uoVcsKUEzMxbPxJDtYJlpPFJNQUn"
    "bgjZ/wPA28/V044poeYU2D1JrfAoIp5tqqUi0D/4bdiBFk79kEkNCcbG7Ij4mWmm9zpvNsxzTYqctl5VTGMHvbdfvfZ"
    "HTCfPU1GLdqz/7KSzm/Bw73YbtJqudQRaQN9UJgkyRfbPRfxqWOza/rRbF/M8CXlPnGbu4mvED6zKkT3DNrnFu2uh4N"
    "8Se8Poi4Id7dZxqfL2x8sJY7WFCtfmC4BPLmcMmThl+gGm6+K3LBraqPGb7zk7VzY/UuyIkm9SIsJLAEXtu8KeOcMMa"
    "y0o5BrEp5EQhd5+GukF0RY0jgZHod8BUFZuIUcX1ZQl/OBF37SRSzhB83ttkOm4ZLdYcRafBYS+dFvwHJxRWLHixUpG"
    "H2PxLtCIoRLDsfit21VSEzwMRbtRcjNNDD8+Bto4deL4MozrtylwOcEMQGX1rp+aEmtgUg0eI34WmRwVw6dhpDplXNi"
    "V3ZbJRH8XrlKgqUbr5Eb/xchirglWSdLh/cHLqRQEIWkpK6+bTzsdEoBQLwlyFevHpheYNByfJ17VwGGoNau7i3M61u"
    "DXAkRi/v1VS/TxOJJuIlpuqXLRLyLkCQpX6E7l0Z0kdh3S+RxEyFFkmZofj3szkimf0F1UrisOEIWxQ8rT/zznlkKvc"
    "GV5IAjhacKfvUc9TxmNmVEO2UiOgX0EcWZ5B34ZmGtiND77AptGtWb4YDLiSiPS1QPajZ10rr63li/ySlHkqx5er/kU"
    "34Ftov6dJTkSXssjFnUw8iz5yXPH6fv8qKnQpYEyRjazIraX3nb+AWX6ELeMACEHfkttwc/KFtj5fN73ZqijIIjKfti"
    "j0ciJYbn5DyciN64ef8mEM93HI9vuxD59uzksXeZCy6jghi7giOrJFSApslWOENPixPYIrvjtlzIa7zkUjlTMAQy92b"
    "vQnRc4QqI2OpnAkYxNb3sd+Ex60fp97tz18L1yn+Mxe7OPXnV3ixnJ+tuhSgLZUWRBOETqFm6rUmE7sU93cZCPH1Pzp"
    "XeJFpu5NNlyeeNUrutzW6UmCCOms5Y31ZmSZTVdGPf7unrtXsHd0Lz131RgDr5iaySuALb9ZuI6kUXzeAt+8ZYgrPe+"
    "m1IjChTKILRYyPnPjx8ualZ6OzJfXy1HsW8WyGR7sbFo43D2t4x0Ju48wu0gncpYKTYPjZcSMHe8aaePGwee9zx708s"
    "HDyVm8Dnz5G5u+1ZOa2obrsXp1NjNzYN3AGE585yvAR6OePN3/LKCsgjrLSIVOvN7u9N5v/OcltdpVgIncD9V6hx9nu"
    "VduQJZ4h1zo3UwM/8IJ4jG3az4e1PKOCik+Tt4WsJmx+TK/ZtHwURbTRRpD98OV5FOoUX0i46npAd8aVnpsSPGVLiH4"
    "iSuaDONImu3S1lUhMiThOLWi2IXtkv57yB9xhIIZKkk7n9qyYnAs/e/ekz8fXd1xWlJI6dwP0aLv8tXxSVe9uNuPuNi"
    "HWCuruXsYOmgkfQi1f8bbV1k9xgVd797w9Of9VTORek7agtmppsgWhhNf7XSfWIAzI8mnfMD/AnYEiKeNEchWMzquTY"
    "1/suWnuaYWHMQnXOAfGYJGlw6aaCb1o4CALiBg9dpGhZ/SlMm/cRysglsMlMA49+f1Ix4xSKdxqJc/h4wBMWeie4BO/"
    "HigQ0pijiX9id8EPvjJTgeZOw2AiV4OBHhDVfwh7drMJ0nu0W2hJ+RtVz+gW9NgrHCLaXzy6UYB9NZDgwKuBZiGT3I6"
    "2+KeP1smYqwVoaSY08uPGORLwqRck9kwkiYJIYL90kOEpVAWdWRCGLq1ctM3eokuRTx8drrYxWG1udJfQ0RvYZ7JOTQ"
    "GecmyqHbLt4EGd+bDZ7kVjJe6GMTf0SN75vk4tJ0IuIqZYN1z5f4z1+iSD+Q3G2sHiHp+BnF+9Wah1lY/eFozYtFidy"
    "vFgE7+iyuoQUl+zwuDhLPQ7gFKyNEIe79Nk8JxAuUlEFd6f0xI9jLKXjPlR1oA7bIuLou04bF5GHpx+fhCmVo09gA/h"
    "Oxd+pI9FciUKr7EaVcyea6xFFESmhvdCK4SC3TfYygAkoLtpdrgpjuDrCZYKGrByLopVFTmYu6p7E1hvnKmjx1kWrBC"
    "TWZI/r9r0+v2qY+OHY17EsKjNf2d5YIcgysbgbC8vQERWfrLLXWcNuG1e9owFRb5Bgib5UKDFvddiFPh19lAMeKsRbZ"
    "VXcHG07wBJRBFzRt696OBYQUbAmdBJHFGYcdODw10g5yBMSL8kei7g2Pk0lUSRAiirZIZDb5GCFPGS5CLu3ZSopHqF0"
    "O8+QiHrIEaZjh4YdZx9nqKg2+yg1BibNYu29wionHnYQLwhOXjr9fQUN6ANRi4J3t+torTDYaG+mIv+IjQKEiu2ob18"
    "6NyAS+TFqlLmA3r/R9ZXgXnAJSCbUc2iOaotandmsI+IVoVbGTauY/WrGOo9dL7SgkIYvIpJ6keMQcsCgJpS1kFsJmU"
    "rmPW5vzVzLW+Wr2TvZ1TzP8rtqZlZs6YVrdB11ChwHRqrzNRwaw6GphMw1+z6hWvU8aZoAJJNc5z8tJkLXbhRgtf2uO"
    "Gd8/yYlIaspx5ujc+Oehfe27HhLuCqE8Evm1O2DCCJvX/B6JGSs92nEvbbWRLRv99A6Vwhw8EtI6rPe1nFVRrZiHwPE"
    "550Iy3xSrY54QmSNsqKicLNZEygIYCU37B4btSvIh6zRhGq2eWQtuKlAA0w9abH8wi/jocWluSfN89EyiQMojG5WIE6"
    "jCpmChh3duZS+4HvFvJCb6za0Knb3ufsErKj7PPKgiuTAPgIcUdxVEZRp7ePwbCW+rN2Z3dodwNTOaRohOf2XE0i1Ow"
    "1dO5XYjxBy3LH227dvAlKRYj2IZyvw/ljluBaIM+bCUPyVcw+8M05RijrOqs8/zfKY089kkF2vD766kK8+VisPK+cxL"
    "x+7xPXBP6jfa4aLirI4S1G/Ben8ekrGDHMA02R/+dxAm6wnGqecNLfAzWNvBTWSKI38ibBpgkR+46v59GJjd7whvQR7"
    "+hFIcKA1VgjlQoVKSbFuO9w8Gfpmm9HIGAqY8WbJF1JkWEI1c2Sf6GoHpwqEeEQiYlIj3w1aubRxxqWhXFrcfefk2p5"
    "M4+SLBE9tSw/jWaxCJ19bRNk3G3VFtLiDouTqhbKzejnzXNw4fBE5nNd87A/xbVS/xiFEi7GAvUoRqzgLdbPKIoWpn3"
    "xj4e2vYu2EifOros3Bf+M8TsskgZr0SnTP7OI0hw6NALRl9dAOa3O02Nhaouni9Fuz1ypMFaluWN3mk0MNf/R8+Vzoc"
    "K6aeYt/J0QxNR89aT4KKdzNTlkigGay4jqIT1JoFbpad/HkgTx8eFTwjYQMnRnmeFDrI2D6t0hbTxNAKCwPj4SSHT2B"
    "p+UJqGKRJFvfHtSiMAG0/YhrX6T1ezvM7Lu+r5al0M7p1cdRAxGfBla84atxMGWIjTALfERdhDxFT2OLSZ6mfWpRjma"
    "LNEDvVq5IYydR51h7krQJu88p9vQJXN7OZvZ79wT129tBXQpbgOboN1qkl1nWz4piOF548D5yLuDIcsejkUT8a7yN/x"
    "n4TAvLTaRLXX8mZE6equzYZ5yDF/lwK/Fj7/kzyToIx1GsDwL/8Yb6JxwR1nxgNpecxIA4Shel6VBmgGQgLGAOPwS3H"
    "44+nCJa7HwrmucfUt10Ly7ja3GxXidAzC977R/2JHeqpjaorDANFPvdon6vTkCkqTruN+OHkTrL/fFBSR/+/uSTc6lQ"
    "TqD76NNH7rWaf/6B+v1Mau5B36FvAdIhD/3lTA6yYq37kEoWJx6WzcMW8WNN+HgD4sE/xpg8Y19RhKm1pn6IrU6IlcY"
    "TZv1GOCwd/malPYHz1ZJv73k9KMlHzH+8e/WgI58jDKQlNOVjFfngSgocgT/oOwHfZzfhIYB8sLOskoctswfCEz5OVu"
    "UZ216PN61EaDNWwtgH7fMgK8+/MwpPPjcBSfone8U87Fc+KDXbGyc3BaeLmuHHOcoHffMUsqYPG2OMyYrs8cmNxwb8i"
    "0r7wq9vsN375s6PR3ak/oKkSFjyy6m1v5z/B6T5VOk7MwAA"
)

ENGLISH_MNEMONIC_WORDS_LIST = decompress_words(ENGLISH_COMPRESSED)
ENGLISH_MNEMONIC_WORDS = set(ENGLISH_MNEMONIC_WORDS_LIST)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/mempool/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/mempool/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/mempool/v1/types.proto\x12\x13\x63ometbft.mempool.v1\"\x12\n\x03Txs\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"9\n\x07Message\x12\'\n\x03txs\x18\x01 \x01(\x0b\x32\x18.cometbft.mempool.v1.TxsH\x00\x42\x05\n\x03sumB6Z4github.com/cometbft/cometbft/api/cometbft/mempool/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.mempool.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/cometbft/cometbft/api/cometbft/mempool/v1'
  _globals['_TXS']._serialized_start=56
  _globals['_TXS']._serialized_end=74
  _globals['_MESSAGE']._serialized_start=76
  _globals['_MESSAGE']._serialized_end=133
# @@protoc_insertion_point(module_scope)



from cometbft.p2p.v1 import types_pb2 as _types_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PexRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PexAddrs(_message.Message):
    __slots__ = ("addrs",)
    ADDRS_FIELD_NUMBER: _ClassVar[int]
    addrs: _containers.RepeatedCompositeFieldContainer[_types_pb2.NetAddress]
    def __init__(self, addrs: _Optional[_Iterable[_Union[_types_pb2.NetAddress, _Mapping]]] = ...) -> None: ...

class Message(_message.Message):
    __slots__ = ("pex_request", "pex_addrs")
    PEX_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PEX_ADDRS_FIELD_NUMBER: _ClassVar[int]
    pex_request: PexRequest
    pex_addrs: PexAddrs
    def __init__(self, pex_request: _Optional[_Union[PexRequest, _Mapping]] = ..., pex_addrs: _Optional[_Union[PexAddrs, _Mapping]] = ...) -> None: ...
